@@ -534,7 +534,9 @@ class DictionaryObject(Dict[Any, Any], PdfObject):
             for gen in rem_gens:
                 loc = pdf.xref[gen]
                 try:
-                    out = min(out, min([x for x in loc.values() if p < x <= p1]))
+                    values = [x for x in loc.values() if p < x <= p1]
+                    if values:
+                        out = min(out, *values)
                 except ValueError:
                     pass
             return out
@@ -1297,7 +1299,7 @@ class ContentStream(DecodedStreamObject):
         operands: List[Union[int, str, PdfObject]] = []
         while True:
             peek = read_non_whitespace(stream)
-            if peek == b"" or peek == 0:
+            if peek in (b"", 0):
                 break
             stream.seek(-1, 1)
             if peek.isalpha() or peek in (b"'", b'"'):
@@ -1462,7 +1464,7 @@ def read_object(
             return read_hex_string_from_stream(stream, forced_encoding)
     elif tok == b"[":
         return ArrayObject.read_from_stream(stream, pdf, forced_encoding)
-    elif tok == b"t" or tok == b"f":
+    elif tok in (b"t", b"f"):
         return BooleanObject.read_from_stream(stream)
     elif tok == b"(":
         return read_string_from_stream(stream, forced_encoding)
